@@ -109,6 +109,8 @@ class StreamResultReceiver(object):
     def __init__(self, processor: Union[AbstractStreamMessageProcess, Callable], rabbit_uri: str, max_watcher_count: int = None, max_processor_count: int = None):
         self.processor = processor
         self.rabbit_uri = rabbit_uri
+        # 默认值，和zcbot_spider保持一致
+        self.queue_expires = 28800
         _max_watcher_count = max_watcher_count or 4
         _max_processor_count = max_processor_count or 24
         self.watcher_executor = ThreadPoolExecutor(max_workers=_max_watcher_count, thread_name_prefix='stream-watcher')
@@ -116,13 +118,13 @@ class StreamResultReceiver(object):
         LOGGER.info(f'[流采结果]监听器初始化 rabbit_uri={self.rabbit_uri}')
 
     def watch(self, exchange_name: str, routing_name: str, queue_name: str):
-        self.watcher_executor.submit(self._receive_message, kwargs={'exchange_name': exchange_name, 'routing_name': routing_name, 'queue_name': queue_name})
+        self.watcher_executor.submit(self._receive_message, exchange_name, routing_name, queue_name)
 
     def _declare(self, exchange_name: str, routing_name: str, queue_name: str):
         # 定义
         connection = pika.BlockingConnection(pika.URLParameters(self.rabbit_uri))
-        channel = self.connection.channel()
-        channel.queue_declare(queue=queue_name)
+        channel = connection.channel()
+        channel.queue_declare(queue=queue_name, arguments={'x-expires': self.queue_expires * 1000})
         channel.exchange_declare(exchange=exchange_name)
         channel.queue_bind(queue=queue_name, exchange=exchange_name, routing_key=routing_name)
         LOGGER.info(f'[流采结果]队列信息 queue={queue_name}, exchange={exchange_name}, routing={routing_name}')
@@ -142,34 +144,27 @@ class StreamResultReceiver(object):
         connection, channel = self._declare(exchange_name, routing_name, queue_name)
         try:
             # 接收
-            for method, properties, body in channel.consume(self.queue_name, auto_ack=False):
+            for method, properties, body in channel.consume(queue_name, auto_ack=False):
                 # 保持通道激活状态
-                if not method or not properties:
+                if not method or not properties or not properties.headers:
                     LOGGER.error(f'[流采结果]无效消息 method={method}, properties={properties}, body={body}')
                     continue
-                try:
-                    headers = properties.headers
-                    if not headers:
-                        LOGGER.error(f'[流采结果]消息结构异常 properties={properties}, body={body}')
-                        continue
-                    # 消息解析并发处理
-                    msg_type = headers.get('msg_type', None)
-                    body_json = json.loads(body.decode())
-                    self.process_executor.submit(_process_func, msg_type, body_json)
-                except (StreamLostError, ConnectionAbortedError):
-                    LOGGER.error(f'[流采结果]服务端关闭链接通道')
-                except Exception:
-                    LOGGER.error(f'[流采结果]解析异常 {traceback.format_exc()}')
+                # 消息解析并发处理
+                msg_type = properties.headers.get('msg_type', None)
+                body_json = json.loads(body.decode())
+                self.processor_executor.submit(_process_func, msg_type, body_json)
                 # 消息确认
                 channel.basic_ack(method.delivery_tag)
+        except (StreamLostError, ConnectionAbortedError):
+            LOGGER.error(f'[流采结果]服务端关闭链接通道StreamLostError,ConnectionAbortedError -> 重连 {traceback.format_exc()}')
         except pika.exceptions.ConnectionClosedByBroker:
-            LOGGER.error(f'[流采结果]链接关闭异常ConnectionClosedByBroker -> 重试 {traceback.format_exc()}')
-        except pika.exceptions.AMQPChannelError as err:
-            LOGGER.error(f'[流采结果]通道关闭异常AMQPChannelError -> 重试 {traceback.format_exc()}')
+            LOGGER.error(f'[流采结果]链接关闭异常ConnectionClosedByBroker -> 重连 {traceback.format_exc()}')
+        except pika.exceptions.AMQPChannelError:
+            LOGGER.error(f'[流采结果]通道关闭异常AMQPChannelError -> 重连 {traceback.format_exc()}')
         except pika.exceptions.AMQPConnectionError:
-            LOGGER.error(f'[流采结果]链接关闭异常AMQPConnectionError -> 重试 {traceback.format_exc()}')
+            LOGGER.error(f'[流采结果]链接关闭异常AMQPConnectionError -> 重连 {traceback.format_exc()}')
         except Exception:
-            LOGGER.error(f'[流采结果]接收过程异常 {traceback.format_exc()}')
+            LOGGER.error(f'[流采结果]接收过程异常 -> 重连 {traceback.format_exc()}')
         finally:
             try:
                 # 关闭链接和通道（链接关闭通道自动关闭）
